/* This file was generated by syncqt. */
#ifndef QT_QT3DQUICKANIMATION_VERSION_H
#define QT_QT3DQUICKANIMATION_VERSION_H

#define QT3DQUICKANIMATION_VERSION_STR "5.15.12"

#define QT3DQUICKANIMATION_VERSION 0x050F0C

#endif // QT_QT3DQUICKANIMATION_VERSION_H
